@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -125,6 +125,42 @@ class DocumentProcessorServiceAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return DocumentProcessorServiceClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> DocumentProcessorServiceTransport:
         """Returns the transport used by the client instance.
@@ -197,6 +233,29 @@ class DocumentProcessorServiceAsyncClient:
     ) -> document_processor_service.ProcessResponse:
         r"""Processes a single document.
 
+        .. code-block:: python
+
+            from google.cloud import documentai_v1
+
+            def sample_process_document():
+                # Create a client
+                client = documentai_v1.DocumentProcessorServiceClient()
+
+                # Initialize request argument(s)
+                inline_document = documentai_v1.Document()
+                inline_document.uri = "uri_value"
+
+                request = documentai_v1.ProcessRequest(
+                    inline_document=inline_document,
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.process_document(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.documentai_v1.types.ProcessRequest, dict]):
                 The request object. Request message for the process
@@ -221,7 +280,7 @@ class DocumentProcessorServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -279,6 +338,30 @@ class DocumentProcessorServiceAsyncClient:
         r"""LRO endpoint to batch process many documents. The output is
         written to Cloud Storage as JSON in the [Document] format.
 
+
+        .. code-block:: python
+
+            from google.cloud import documentai_v1
+
+            def sample_batch_process_documents():
+                # Create a client
+                client = documentai_v1.DocumentProcessorServiceClient()
+
+                # Initialize request argument(s)
+                request = documentai_v1.BatchProcessRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.batch_process_documents(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.documentai_v1.types.BatchProcessRequest, dict]):
                 The request object. Request message for batch process
@@ -306,7 +389,7 @@ class DocumentProcessorServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -372,6 +455,34 @@ class DocumentProcessorServiceAsyncClient:
         r"""Send a document for Human Review. The input document
         should be processed by the specified processor.
 
+
+        .. code-block:: python
+
+            from google.cloud import documentai_v1
+
+            def sample_review_document():
+                # Create a client
+                client = documentai_v1.DocumentProcessorServiceClient()
+
+                # Initialize request argument(s)
+                inline_document = documentai_v1.Document()
+                inline_document.uri = "uri_value"
+
+                request = documentai_v1.ReviewDocumentRequest(
+                    inline_document=inline_document,
+                    human_review_config="human_review_config_value",
+                )
+
+                # Make the request
+                operation = client.review_document(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.documentai_v1.types.ReviewDocumentRequest, dict]):
                 The request object. Request message for review document
@@ -400,7 +511,7 @@ class DocumentProcessorServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([human_review_config])
         if request is not None and has_flattened_params:
